<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>AppChooserDialog</name>
    <message>
        <location filename="../app-chooser-dialog.ui" line="14"/>
        <source>Choose an Application</source>
        <translation>Valitse sovellus</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="36"/>
        <source>Installed Applications</source>
        <translation>Asennetut sovellukset</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="46"/>
        <source>Custom Command</source>
        <translation>Mukautettu komento</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="52"/>
        <source>Command line to execute:</source>
        <translation>Ajettava komentorivi:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="78"/>
        <source>Application name:</source>
        <translation>Sovelluksen nimi:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="62"/>
        <source>&lt;b&gt;These special codes can be used in the command line:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Represents a single file name&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Represents multiple file names&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Represents a single URI of the file&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Represents multiple URIs&lt;/li&gt;
&lt;/ul&gt;</source>
        <translation>&lt;b&gt;Komentorivillä voi käyttää näitä erikoiskoodeja:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Yksittäinen tiedostonimi&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Useita tiedostonimiä&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Yksittäisen tiedoston URI&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Monen tiedoston URI:t&lt;/li&gt;
&lt;/ul&gt;</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="98"/>
        <source>Keep terminal window open after command execution</source>
        <translation>Pidä pääteikkuna auki komennon suorittua</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="88"/>
        <source>Execute in terminal emulator</source>
        <translation>Suorita pääte-emulaattorissa</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="109"/>
        <source>Set selected application as default action of this file type</source>
        <translation>Käytä valittua sovellusta oletuksena tälle tiedostotyypille</translation>
    </message>
</context>
<context>
    <name>EditBookmarksDialog</name>
    <message>
        <location filename="../edit-bookmarks.ui" line="14"/>
        <source>Edit Bookmarks</source>
        <translation>Muokkaa kirjanmerkkejä</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="49"/>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="54"/>
        <source>Location</source>
        <translation>Sijainti</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="64"/>
        <source>&amp;Add Item</source>
        <translation>&amp;Lisää kohde</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="74"/>
        <source>&amp;Remove Item</source>
        <translation>P&amp;oista kohde</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="20"/>
        <source>Use drag and drop to reorder the items</source>
        <translation>Muuta kohteiden järjestystä vetämällä ja pudottamalla</translation>
    </message>
</context>
<context>
    <name>ExecFileDialog</name>
    <message>
        <location filename="../exec-file.ui" line="14"/>
        <source>Execute file</source>
        <translation>Suorita tiedosto</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="42"/>
        <source>&amp;Open</source>
        <translation>&amp;Avaa</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="55"/>
        <source>E&amp;xecute</source>
        <translation>&amp;Suorita</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="65"/>
        <source>Execute in &amp;Terminal</source>
        <translation>Suorita &amp;päätteessä</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="88"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="102"/>
        <source>Remember for next files of this kind</source>
        <translation>Muista tämän tyyppisille tiedostoille</translation>
    </message>
</context>
<context>
    <name>FileDialog</name>
    <message>
        <location filename="../filedialog.ui" line="22"/>
        <source>Path:</source>
        <translation>Polku:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="65"/>
        <source>File name:</source>
        <translation>Tiedostonimi:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="85"/>
        <source>File type:</source>
        <translation>Tiedostotyyppi:</translation>
    </message>
</context>
<context>
    <name>FileOperationDialog</name>
    <message>
        <location filename="../file-operation-dialog.ui" line="42"/>
        <source>Destination:</source>
        <translation>Kohde:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="65"/>
        <source>Processing:</source>
        <translation>Prosessoidaan:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="78"/>
        <source>Preparing...</source>
        <translation>Valmistellaan...</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="85"/>
        <source>Progress:</source>
        <translation>Tilanne:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="119"/>
        <source>Time remaining:</source>
        <translation>Aikaa jäljellä:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="99"/>
        <source>Files processed:</source>
        <translation>Tiedostoja prosessoitu:</translation>
    </message>
</context>
<context>
    <name>FilePropsDialog</name>
    <message>
        <location filename="../file-props.ui" line="14"/>
        <source>File Properties</source>
        <translation>Tiedoston ominaisuudet</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="41"/>
        <source>General</source>
        <translation>Perustiedot</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="80"/>
        <source>Location:</source>
        <translation>Sijainti:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="132"/>
        <source>File type:</source>
        <translation>Tiedostotyyppi:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="155"/>
        <source>MIME type:</source>
        <translation>MIME-tyyppi:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="195"/>
        <source>File size:</source>
        <translation>Koko:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="218"/>
        <source>On-disk size:</source>
        <translation>Koko levyllä:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="241"/>
        <source>Last modified:</source>
        <translation>Viimeksi muutettu:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="106"/>
        <source>Link target:</source>
        <translation>Linkin kohde:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="178"/>
        <source>Open With:</source>
        <translation>Avaa sovelluksessa:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="264"/>
        <source>Last accessed:</source>
        <translation>Viimeksi käytetty:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="287"/>
        <source>Created:</source>
        <translation>Luotu:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="310"/>
        <source>Contains:</source>
        <translation>Sisältää:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="330"/>
        <source>Emblem:</source>
        <translation>Tunnuskuva:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="342"/>
        <source>Choose emblem</source>
        <translation>Valitse tunnuskuva</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="361"/>
        <source>Clear emblem</source>
        <translation>Poista tunnuskuva</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="397"/>
        <source>Device Usage:</source>
        <translation>Koko levyllä:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="424"/>
        <source>Permissions</source>
        <translation>Käyttöoikeudet</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="439"/>
        <source>Ownership</source>
        <translation>Omistajuus</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="473"/>
        <location filename="../file-props.ui" line="528"/>
        <location filename="../file-props.ui" line="642"/>
        <source>Group:</source>
        <translation>Ryhmä:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="457"/>
        <location filename="../file-props.ui" line="511"/>
        <location filename="../file-props.ui" line="590"/>
        <source>Owner:</source>
        <translation>Omistaja:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="492"/>
        <source>Access Control</source>
        <translation>Käyttöluvat</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="545"/>
        <location filename="../file-props.ui" line="694"/>
        <source>Other:</source>
        <translation>Muut:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="562"/>
        <source>Make the file executable</source>
        <translation>Tiedoston voi suorittaa</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="603"/>
        <location filename="../file-props.ui" line="655"/>
        <location filename="../file-props.ui" line="707"/>
        <source>Read</source>
        <translation>Luku</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="616"/>
        <location filename="../file-props.ui" line="668"/>
        <location filename="../file-props.ui" line="720"/>
        <source>Write</source>
        <translation>Kirjoitus</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="629"/>
        <location filename="../file-props.ui" line="681"/>
        <location filename="../file-props.ui" line="733"/>
        <source>Execute</source>
        <translation>Suoritus</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="749"/>
        <source>Sticky</source>
        <translation>Lukittu omistajalle</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="756"/>
        <source>SetUID</source>
        <translation>Aseta UID</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="763"/>
        <source>SetGID</source>
        <translation>Aseta GID</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="792"/>
        <source>Advanced Mode</source>
        <translation>Lisäasetukset</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserComboBox</name>
    <message>
        <location filename="../appchoosercombobox.cpp" line="66"/>
        <source>Customize</source>
        <translation>Muokkaa</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserDialog</name>
    <message>
        <location filename="../appchooserdialog.cpp" line="268"/>
        <source>Select an application to open &quot;%1&quot; files</source>
        <translation>Valitse sovellus avaamaan &quot;%1&quot;-tiedostoja</translation>
    </message>
</context>
<context>
    <name>Fm::CreateNewMenu</name>
    <message>
        <location filename="../createnewmenu.cpp" line="62"/>
        <source>Folder</source>
        <translation>Kansio</translation>
    </message>
    <message>
        <location filename="../createnewmenu.cpp" line="66"/>
        <source>Blank File</source>
        <translation>Tyhjä tiedosto</translation>
    </message>
</context>
<context>
    <name>Fm::DirListJob</name>
    <message>
        <location filename="../core/dirlistjob.cpp" line="48"/>
        <source>The specified directory &apos;%1&apos; is not valid</source>
        <translation>Määritetty kansio &apos;%1&apos; ei kelpaa</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeModel</name>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="84"/>
        <source>Loading...</source>
        <translation>Ladataan...</translation>
    </message>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="267"/>
        <location filename="../dirtreemodelitem.cpp" line="311"/>
        <location filename="../dirtreemodelitem.cpp" line="409"/>
        <source>&lt;No sub folders&gt;</source>
        <translation>&lt;Ei alikansioita&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeView</name>
    <message>
        <location filename="../dirtreeview.cpp" line="217"/>
        <source>Open in New T&amp;ab</source>
        <translation>&amp;Avaa uuteen välilehteen</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="221"/>
        <source>Open in New Win&amp;dow</source>
        <translation>Avaa uuteen &amp;ikkunaan</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="226"/>
        <source>Open in Termina&amp;l</source>
        <translation>Avaa &amp;pääte tähän</translation>
    </message>
</context>
<context>
    <name>Fm::DndActionMenu</name>
    <message>
        <location filename="../dndactionmenu.cpp" line="32"/>
        <source>Copy here</source>
        <translation>Kopioi tähän</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="35"/>
        <source>Move here</source>
        <translation>Siirrä tähän</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="38"/>
        <source>Create symlink here</source>
        <translation>Luo symbolinen linkki tähän</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="42"/>
        <source>Cannot drop here</source>
        <translation>Ei voi pudottaa tänne</translation>
    </message>
</context>
<context>
    <name>Fm::EditBookmarksDialog</name>
    <message>
        <location filename="../editbookmarksdialog.cpp" line="84"/>
        <source>New bookmark</source>
        <translation>Uusi kirjanmerkki</translation>
    </message>
</context>
<context>
    <name>Fm::ExecFileDialog</name>
    <message>
        <location filename="../execfiledialog.cpp" line="40"/>
        <source>This file &apos;%1&apos; seems to be a desktop entry.
What do you want to do with it?</source>
        <translation>Tiedosto &apos;%1&apos; näyttää olevan työpöytätietue.
Mitä tehdä sen kanssa?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="46"/>
        <source>This text file &apos;%1&apos; seems to be an executable script.
What do you want to do with it?</source>
        <translation>Tiedosto &apos;%1&apos; näyttää olevan suoritettava komentosarja.
Mitä tehdä sen kanssa?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="51"/>
        <source>This file &apos;%1&apos; is executable. Do you want to execute it?</source>
        <translation>Tiedosto &apos;%1&apos; on ohjelma. Haluatko suorittaa sen?</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialog</name>
    <message>
        <location filename="../filedialog.cpp" line="115"/>
        <source>Go Back</source>
        <translation>Palaa takaisin</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="116"/>
        <source>Alt+Left</source>
        <comment>Go Back</comment>
        <translation>Alt+Vasen nuoli</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="122"/>
        <source>Go Forward</source>
        <translation>Siirry eteenpäin</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="123"/>
        <source>Alt+Right</source>
        <comment>Go Forward</comment>
        <translation>Alt+Oikea nuoli</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="130"/>
        <source>Reload</source>
        <translation>Päivitä</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="131"/>
        <source>F5</source>
        <comment>Reload</comment>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="148"/>
        <source>Create Folder</source>
        <translation>Luo kansio</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="164"/>
        <source>Icon View</source>
        <translation>Kuvakenäkymä</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="168"/>
        <source>Thumbnail View</source>
        <translation>Pienoiskuvanäkymä</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="172"/>
        <source>Compact View</source>
        <translation>Tiivis näkymä</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="176"/>
        <source>Detailed List View</source>
        <translation>Yksityiskohtainen näkymä</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="184"/>
        <source>Icon Sizes</source>
        <translation>Kuvakekoot</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="186"/>
        <source>Size of big icons:</source>
        <translation>Suuren kuvakkeen koko:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="193"/>
        <source>Size of small icons:</source>
        <translation>Pienen kuvakkeen koko:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="200"/>
        <source>Size of thumbnails:</source>
        <translation>Pienoiskuvan koko:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="216"/>
        <source>Show Hidden</source>
        <translation>Näytä piilotetut</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="228"/>
        <source>Show Thumbnails</source>
        <translation>Näytä pienoiskuvat</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="233"/>
        <source>Show File Tooltips</source>
        <translation>Näytä tiedostojen työkaluvihjeet</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="240"/>
        <source>Smooth Scrolling</source>
        <translation>Tasainen vieritys</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="255"/>
        <source>Options</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="605"/>
        <location filename="../filedialog.cpp" line="1064"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="605"/>
        <source>Please select a file</source>
        <translation>Valitse tiedosto</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="681"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 on jo olemassa.
Korvataanko se?</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1026"/>
        <source>Path &quot;%1&quot; does not exist</source>
        <translation>Polkua &quot;%1&quot; ei löydy</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1040"/>
        <source>&quot;%1&quot; is not a directory</source>
        <translation>&quot;%1&quot; ei ole hakemisto</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1050"/>
        <source>&quot;%1&quot; is not a file</source>
        <translation>&quot;%1&quot; ei ole tiedosto</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1204"/>
        <location filename="../filedialog.cpp" line="1321"/>
        <source>&amp;Open</source>
        <translation>&amp;Avaa</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1207"/>
        <location filename="../filedialog.cpp" line="1329"/>
        <source>&amp;Save</source>
        <translation>&amp;Tallenna</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1214"/>
        <source>All Files (*)</source>
        <translation>Kaikki tiedostot (*)</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogHelper</name>
    <message>
        <location filename="../filedialoghelper.cpp" line="140"/>
        <source>Open File</source>
        <translation>Avaa tiedosto</translation>
    </message>
    <message>
        <location filename="../filedialoghelper.cpp" line="141"/>
        <source>Save File</source>
        <translation>Tallenna tiedosto</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogIconSizeAction</name>
    <message>
        <location filename="../filedialog_p.h" line="40"/>
        <source> px</source>
        <translation> px</translation>
    </message>
</context>
<context>
    <name>Fm::FileMenu</name>
    <message>
        <location filename="../filemenu.cpp" line="86"/>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="90"/>
        <source>Open With...</source>
        <translation>Avaa sovelluksessa...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="419"/>
        <source>Many files</source>
        <translation>Useita tiedostoja</translation>
    </message>
    <message numerus="yes">
        <location filename="../filemenu.cpp" line="420"/>
        <source>Do you want to open these %1 files?</source>
        <translation>
            <numerusform>Haluatko avata tämän %1 tiedoston?</numerusform>
            <numerusform>Haluatko avata nämä %1 tiedostoa?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="181"/>
        <source>Other Applications</source>
        <translation>Muut sovellukset</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="188"/>
        <source>Create &amp;New</source>
        <translation>&amp;Luo uusi</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="207"/>
        <source>&amp;Restore</source>
        <translation>P&amp;alauta</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="217"/>
        <source>Cut</source>
        <translation>Leikkaa</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="221"/>
        <source>Copy</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="225"/>
        <source>Paste</source>
        <translation>Liitä</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="229"/>
        <location filename="../filemenu.cpp" line="547"/>
        <source>&amp;Move to Trash</source>
        <translation>Siirrä &amp;roskakoriin</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="233"/>
        <source>Rename</source>
        <translation>Uudelleennimeä</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="289"/>
        <source>Mount</source>
        <translation>Liitä asema</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="303"/>
        <source>Unmount</source>
        <translation>Irrota asema</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="317"/>
        <source>Eject</source>
        <translation>Poista asema tai levy</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="338"/>
        <source>Extract to...</source>
        <translation>Pura kohteeseen...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="346"/>
        <source>Extract Here</source>
        <translation>Pura tähän</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="353"/>
        <source>Compress</source>
        <translation>Pakkaa</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="362"/>
        <source>Properties</source>
        <translation>Ominaisuudet</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="376"/>
        <source>Trust selected executables</source>
        <translation>Luota valittuja suoritettavia</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="377"/>
        <source>Trust this executable</source>
        <translation>Luota tätä suoritettavaa</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="482"/>
        <source>Output</source>
        <translation>Tuloste</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="211"/>
        <location filename="../filemenu.cpp" line="547"/>
        <source>&amp;Delete</source>
        <translation>&amp;Poista</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperation</name>
    <message>
        <location filename="../fileoperation.cpp" line="317"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="318"/>
        <source>Some files cannot be moved to trash can because the underlying file systems don&apos;t support this operation.
Do you want to delete them instead?</source>
        <translation>Joitain tiedostoja ei voida siirtää roskakoriin, koska käytettävät tiedostojärjestelmät eivät tue tätä toimenpidettä.
Poistetaanko tiedostot?</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="404"/>
        <location filename="../fileoperation.cpp" line="422"/>
        <source>Confirm</source>
        <translation>Kyllä</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileoperation.cpp" line="405"/>
        <source>Do you want to delete the selected file(s)?</source>
        <translation>
            <numerusform>Haluatko poistaa valitun tiedoston?</numerusform>
            <numerusform>Haluatko poistaa valitut tiedostot?</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../fileoperation.cpp" line="423"/>
        <source>Do you want to move the selected file(s) to trash can?</source>
        <translation>
            <numerusform>Siirretäänkö valittu tiedosto roskakoriin?</numerusform>
            <numerusform>Siirretäänkö valitut tiedostot roskakoriin?</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Fm::FileOperationDialog</name>
    <message>
        <location filename="../fileoperationdialog.cpp" line="46"/>
        <source>Move Files</source>
        <translation>Siirrä tiedostot</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="47"/>
        <source>Moving the following files to destination folder:</source>
        <translation>Siirretään seuraavat tiedostot kohdekansioon:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="50"/>
        <source>Copy Files</source>
        <translation>Kopioi tiedostot</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="51"/>
        <source>Copying the following files to destination folder:</source>
        <translation>Kopioidaan seuraavat tiedostot kohdekansioon:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="54"/>
        <source>Trash Files</source>
        <translation>Siirrä roskakoriin</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="55"/>
        <source>Moving the following files to trash can:</source>
        <translation>Siirretään seuraavat tiedostot roskakoriin:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="58"/>
        <source>Delete Files</source>
        <translation>Poista tiedostot</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="59"/>
        <source>Deleting the following files:</source>
        <translation>Poistetaan seuraavat tiedostot:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="64"/>
        <source>Create Symlinks</source>
        <translation>Luo symbolisiä linkkejä</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="65"/>
        <source>Creating symlinks for the following files:</source>
        <translation>Luodaan symbolisiä linkkejä seuraaville tiedostoille:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="68"/>
        <source>Change Attributes</source>
        <translation>Muuta määritteitä</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="69"/>
        <source>Changing attributes of the following files:</source>
        <translation>Muutetaan seuraavien tiedostojen määritteitä:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="74"/>
        <source>Restore Trashed Files</source>
        <translation>Palauta tiedostot roskakorista</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="75"/>
        <source>Restoring the following files from trash can:</source>
        <translation>Palautetaan seuraavia tiedostoja roskakorista:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="149"/>
        <location filename="../fileoperationdialog.cpp" line="155"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
</context>
<context>
    <name>Fm::FilePropsDialog</name>
    <message>
        <location filename="../filepropsdialog.cpp" line="167"/>
        <source>View folder content</source>
        <translation>Selaa kansion sisältöä</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="168"/>
        <source>View and modify folder content</source>
        <translation>Selaa ja muokkaa kansion sisältöä</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="172"/>
        <source>Read</source>
        <translation>Luku</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="173"/>
        <source>Read and write</source>
        <translation>Luku ja kirjoitus</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="175"/>
        <source>Forbidden</source>
        <translation>Ei oikeuksia</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="292"/>
        <source>Files of different types</source>
        <translation>Erityyppisiä tiedostoja</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="315"/>
        <location filename="../filepropsdialog.cpp" line="322"/>
        <location filename="../filepropsdialog.cpp" line="329"/>
        <source>N/A</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="333"/>
        <source>Multiple Files</source>
        <translation>Useita tiedostoja</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="410"/>
        <source>%p% used</source>
        <translation>%p% käytössä</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="411"/>
        <source>%1 Free of %2</source>
        <translation>%1 vapaana sijainnissa %2</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="457"/>
        <source>no file</source>
        <translation>ei tiedostoja</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="459"/>
        <source>one file</source>
        <translation>yksi tiedosto</translation>
    </message>
    <message numerus="yes">
        <location filename="../filepropsdialog.cpp" line="461"/>
        <source>%Ln files</source>
        <translation>
            <numerusform>%Ln tiedosto</numerusform>
            <numerusform>%Ln tiedostoa</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="495"/>
        <location filename="../filepropsdialog.cpp" line="540"/>
        <source>Select an icon</source>
        <translation>Valitse kuvake</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="497"/>
        <location filename="../filepropsdialog.cpp" line="542"/>
        <source>Images (*.png *.xpm *.svg *.svgz )</source>
        <translation>Kuvat (*.png *.xpm *.svg *.svgz)</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="648"/>
        <source>Apply changes</source>
        <translation>Toteuta muutokset</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="649"/>
        <source>Do you want to recursively apply these changes to all files and sub-folders?</source>
        <translation>Hyväksytäänkö nämä muutokset rekursiivisesti kaikkiin tiedostoihin ja alihakemistoihin?</translation>
    </message>
</context>
<context>
    <name>Fm::FileSearchDialog</name>
    <message>
        <location filename="../filesearchdialog.cpp" line="157"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="157"/>
        <source>You should add at least one directory to search.</source>
        <translation>Lisää ainakin yksi hakemisto, josta etsiä.</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="164"/>
        <source>Select a folder</source>
        <translation>Valitse kansio</translation>
    </message>
</context>
<context>
    <name>Fm::FileTransferJob</name>
    <message>
        <location filename="../core/filetransferjob.cpp" line="492"/>
        <source>Cannot copy a directory into itself!</source>
        <translation>Hakemistoa ei voi kopioida itseensä!</translation>
    </message>
    <message>
        <location filename="../core/filetransferjob.cpp" line="543"/>
        <source>Cannot create a link on non-native filesystem</source>
        <translation>Epänatiivinen kohdetiedostojärjestelmä ei tue linkkien luomista</translation>
    </message>
</context>
<context>
    <name>Fm::FolderMenu</name>
    <message>
        <location filename="../foldermenu.cpp" line="58"/>
        <source>Empty Trash</source>
        <translation>Tyhjennä roskakori</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="70"/>
        <source>Create &amp;New</source>
        <translation>&amp;Luo uusi</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="75"/>
        <source>&amp;Paste</source>
        <translation>L&amp;iitä</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="89"/>
        <source>Select &amp;All</source>
        <translation>&amp;Valitse kaikki</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="100"/>
        <source>Sorting</source>
        <translation>Lajittele</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="105"/>
        <source>Show Hidden</source>
        <translation>Näytä piilotetut</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="140"/>
        <source>Folder Pr&amp;operties</source>
        <translation>&amp;Kansion ominaisuudet</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="183"/>
        <source>Output</source>
        <translation>Tuloste</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="205"/>
        <source>By File Name</source>
        <translation>Tiedostonimen mukaan</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="206"/>
        <source>By Modification Time</source>
        <translation>Muokkausajan mukaan</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="207"/>
        <source>By Creation Time</source>
        <translation>Luomisajan mukaan</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="210"/>
        <source>By Deletion Time</source>
        <translation>Poistoajan mukaan</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="213"/>
        <source>By File Size</source>
        <translation>Tiedostokoon mukaan</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="214"/>
        <source>By File Type</source>
        <translation>Tiedostotyypin mukaan</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="215"/>
        <source>By File Owner</source>
        <translation>Tiedoston omistajan mukaan</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="216"/>
        <source>By File Group</source>
        <translation>Tiedostoryhmän mukaan</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="222"/>
        <source>Ascending</source>
        <translation>A-Ö</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="227"/>
        <source>Descending</source>
        <translation>Ö-A</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="244"/>
        <source>Folder First</source>
        <translation>Kansiot ensin</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="252"/>
        <source>Hidden Last</source>
        <translation>Piilotetut viimeisenä</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="260"/>
        <source>Case Sensitive</source>
        <translation>Kirjainkokoerotus</translation>
    </message>
</context>
<context>
    <name>Fm::FolderModel</name>
    <message>
        <location filename="../foldermodel.cpp" line="306"/>
        <source>Location:</source>
        <translation>Sijainti:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="310"/>
        <source>File type:</source>
        <translation>Tiedostotyyppi:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="315"/>
        <source>File size:</source>
        <translation>Tiedostokoko:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="319"/>
        <source>Last modified:</source>
        <translation>Muokattu viimeksi:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="320"/>
        <source>Last accessed:</source>
        <translation>Viimeksi käytetty:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="321"/>
        <source>N/A</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="323"/>
        <source>Created:</source>
        <translation>Luotu:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="328"/>
        <source>Owner:</source>
        <translation>Omistaja:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="329"/>
        <source>Group:</source>
        <translation>Ryhmä:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="396"/>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="399"/>
        <source>Type</source>
        <translation>Tyyppi</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="402"/>
        <source>Size</source>
        <translation>Koko</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="405"/>
        <source>Modified</source>
        <translation>Muokattu</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="408"/>
        <source>Created</source>
        <translation>Luotu</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="411"/>
        <source>Deleted</source>
        <translation>Poistettu</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="414"/>
        <source>Owner</source>
        <translation>Omistaja</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="417"/>
        <source>Group</source>
        <translation>Ryhmä</translation>
    </message>
</context>
<context>
    <name>Fm::FolderViewTreeView</name>
    <message>
        <location filename="../folderview.cpp" line="410"/>
        <source>Auto-resize columns</source>
        <translation>Automaattiset sarakeleveydet</translation>
    </message>
    <message>
        <location filename="../folderview.cpp" line="427"/>
        <source>Visible Columns</source>
        <translation>Näkyvät sarakkeet</translation>
    </message>
</context>
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Lihavoitu</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Kursivoitu</translation>
    </message>
</context>
<context>
    <name>Fm::MountOperationPasswordDialog</name>
    <message>
        <location filename="../mountoperationpassworddialog.cpp" line="42"/>
        <source>&amp;Connect</source>
        <translation>&amp;Yhdistä</translation>
    </message>
</context>
<context>
    <name>Fm::PathBar</name>
    <message>
        <location filename="../pathbar.cpp" line="123"/>
        <source>&amp;Edit Path</source>
        <translation>&amp;Muokkaa polkua</translation>
    </message>
    <message>
        <location filename="../pathbar.cpp" line="126"/>
        <source>&amp;Copy Path</source>
        <translation>&amp;Kopioi polku</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesModel</name>
    <message>
        <location filename="../placesmodel.cpp" line="46"/>
        <source>Places</source>
        <translation>Sijainnit</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="54"/>
        <source>Desktop</source>
        <translation>Työpöytä</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="60"/>
        <source>Computer</source>
        <translation>Tietokone</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="68"/>
        <source>Applications</source>
        <translation>Sovellukset</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="77"/>
        <source>Network</source>
        <translation>Verkko</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="81"/>
        <source>Devices</source>
        <translation>Laitteet</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="136"/>
        <source>Bookmarks</source>
        <translation>Kirjanmerkit</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="227"/>
        <source>Trash</source>
        <translation>Roskakori</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesView</name>
    <message>
        <location filename="../placesview.cpp" line="563"/>
        <source>Open in New Tab</source>
        <translation>Avaa uuteen välilehteen</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="567"/>
        <source>Open in New Window</source>
        <translation>Avaa uuteen ikkunaan</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="580"/>
        <source>Empty Trash</source>
        <translation>Tyhjennä roskakori</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="600"/>
        <location filename="../placesview.cpp" line="667"/>
        <source>Hide</source>
        <translation>Piilota</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="617"/>
        <source>Move Bookmark Up</source>
        <translation>Siirrä kirjanmerkkiä ylös</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="624"/>
        <source>Move Bookmark Down</source>
        <translation>Siirrä kirjanmerkkiä alas</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="629"/>
        <source>Rename Bookmark</source>
        <translation>Nimeä kirjanmerkki uudelleen</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="633"/>
        <source>Remove Bookmark</source>
        <translation>Poista kirjanmerkki</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="643"/>
        <location filename="../placesview.cpp" line="681"/>
        <source>Unmount</source>
        <translation>Irrota</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="647"/>
        <source>Mount</source>
        <translation>Liitä</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="653"/>
        <source>Eject</source>
        <translation>Poista asema tai levy</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="658"/>
        <source>Safely Remove</source>
        <translation>Poista turvallisesti</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="693"/>
        <source>Show All Entries</source>
        <translation>Näytä kaikki kohteet</translation>
    </message>
</context>
<context>
    <name>Fm::RenameDialog</name>
    <message>
        <location filename="../renamedialog.cpp" line="58"/>
        <location filename="../renamedialog.cpp" line="77"/>
        <source>Type: %1
Size: %2
Modified: %3</source>
        <translation>Tyyppi: %1
Koko: %2
Muokattu: %3</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="64"/>
        <location filename="../renamedialog.cpp" line="83"/>
        <source>Type: %1
Modified: %2</source>
        <translation>Tyyppi: %1
Muokattu: %2</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="104"/>
        <source>&amp;Overwrite</source>
        <translation>&amp;Korvaa</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="106"/>
        <source>&amp;Rename</source>
        <translation>&amp;Nimeä uudelleen</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="116"/>
        <source>&lt;p&gt;&lt;b&gt;The file cannot overwrite itself.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Please select another name.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Tiedostoa ei voi korvata itsellään.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Valitse toinen nimi.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::SidePane</name>
    <message>
        <location filename="../sidepane.cpp" line="46"/>
        <source>Lists</source>
        <translation>Luettelot</translation>
    </message>
    <message>
        <location filename="../sidepane.cpp" line="47"/>
        <source>Directory Tree</source>
        <translation>Hakemistopuu</translation>
    </message>
</context>
<context>
    <name>Fm::UntrashJob</name>
    <message>
        <location filename="../core/untrashjob.cpp" line="35"/>
        <source>Cannot untrash file &apos;%s&apos;: original path not known</source>
        <translation>Kohdetta &apos;%s&apos; ei voi palauttaa roskakorista: alkuperäistä polkua ei tiedetä</translation>
    </message>
</context>
<context>
    <name>MountOperationPasswordDialog</name>
    <message>
        <location filename="../mount-operation-password.ui" line="20"/>
        <source>Mount</source>
        <translation>Liitä</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="48"/>
        <source>Connect &amp;anonymously</source>
        <translation>Yhdistä &amp;anonyymisti</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="58"/>
        <source>Connect as u&amp;ser:</source>
        <translation>Yhdistä k&amp;äyttäjänä:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="76"/>
        <source>&amp;Username:</source>
        <translation>&amp;Käyttäjätunnus:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="108"/>
        <source>&amp;Password:</source>
        <translation>&amp;Salasana:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="89"/>
        <source>&amp;Domain:</source>
        <translation>A&amp;luenimi:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="127"/>
        <source>Forget password &amp;immediately</source>
        <translation>&amp;Unohda salasana heti</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="137"/>
        <source>Session length is determined by password manager</source>
        <translation>Salasanahallinta määrittelee istunnon pituuden</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="140"/>
        <source>Remember password for &amp;this session</source>
        <translation>&amp;Muista salasana istunnon ajan</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="150"/>
        <source>Remember &amp;forever</source>
        <translation>Muista a&amp;ina</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../utilities.cpp" line="170"/>
        <source>Rename File</source>
        <translation>Nimeä tiedosto uudelleen</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="171"/>
        <source>Please enter a new name:</source>
        <translation>Uusi nimi:</translation>
    </message>
    <message>
        <location filename="../filelauncher.cpp" line="124"/>
        <location filename="../filepropsdialog.cpp" line="674"/>
        <location filename="../mountoperation.cpp" line="315"/>
        <location filename="../utilities.cpp" line="154"/>
        <location filename="../utilities.cpp" line="318"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="230"/>
        <source>Create Folder</source>
        <translation>Luo kansio</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="231"/>
        <source>Create File</source>
        <translation>Luo tiedosto</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="235"/>
        <source>Please enter a new file name:</source>
        <translation>Uusi nimi:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="236"/>
        <source>New file</source>
        <translation>Uusi tiedosto</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="240"/>
        <source>Please enter a new folder name:</source>
        <translation>Uusi nimi:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="241"/>
        <source>New folder</source>
        <translation>Uusi kansio</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="246"/>
        <source>Enter a name for the new %1:</source>
        <translation>Nimi mallille %1:</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="692"/>
        <source>Custom Icon Error</source>
        <translation>Virhe kustomoidun kuvakkeen kanssa</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="41"/>
        <source>The path is not mounted.</source>
        <translation>Polkua ei ole liitetty.</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="319"/>
        <source>Invalid desktop entry file: &apos;%1&apos;</source>
        <translation>Virheellinen työpöytätietue: &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="355"/>
        <source>No default application is set to launch &apos;%1&apos;</source>
        <translation>Oletussovellusta ei ole määritetty tyypille &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="396"/>
        <source>Cannot set working directory to &apos;%1&apos;: %2</source>
        <translation>Työhakemistoksi ei voi asettaa ”%s”: %s</translation>
    </message>
    <message>
        <location filename="../placesmodelitem.cpp" line="127"/>
        <source>Identifier: </source>
        <translation>Tunniste: </translation>
    </message>
    <message>
        <location filename="../foldermodelitem.cpp" line="61"/>
        <location filename="../foldermodelitem.cpp" line="74"/>
        <source>N/A</source>
        <translation>-</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <location filename="../rename-dialog.ui" line="14"/>
        <source>Confirm to replace files</source>
        <translation>Vahvista tiedostojen korvaus</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="35"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;There is already a file with the same name in this location.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Do you want to replace the existing file?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Sijainnissa on jo tiedosto samalla nimellä.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Korvataanko tiedosto?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="76"/>
        <source>with the following file?</source>
        <translation>seuraavalla tiedostolla?</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="122"/>
        <source>&amp;File name:</source>
        <translation>Tiedostonimi:</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="137"/>
        <source>Apply this option to all existing files</source>
        <translation>Tee sama kaikille</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../filesearch.ui" line="14"/>
        <source>Search Files</source>
        <translation>Etsi tiedostoja</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="29"/>
        <source>Name/Location</source>
        <translation>Nimi/sijainti</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="35"/>
        <source>File Name Patterns:</source>
        <translation>Tiedostonimikuviot:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="44"/>
        <source>*</source>
        <translation>*</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="58"/>
        <source>Use regular expression</source>
        <translation>Käytä säännöllistä lauseketta</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="71"/>
        <source>Places to Search:</source>
        <translation>Etsittävät sijainnit:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="84"/>
        <source>&amp;Add</source>
        <translation>&amp;Lisää</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="96"/>
        <source>&amp;Remove</source>
        <translation>&amp;Poista</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="132"/>
        <source>Search for hidden files</source>
        <translation>Etsi piilotiedostot</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="143"/>
        <source>File Type</source>
        <translation>Tiedostotyyppi</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="149"/>
        <source>Only search for files of following types:</source>
        <translation>Etsi vain tämän tyyppisiä:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="155"/>
        <source>Text files</source>
        <translation>Tekstitiedostot</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="162"/>
        <source>Image files</source>
        <translation>Kuvatiedostot</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="169"/>
        <source>Audio files</source>
        <translation>Äänitiedostot</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="176"/>
        <source>Video files</source>
        <translation>Videotiedostot</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="183"/>
        <source>Documents</source>
        <translation>Asiakirjat</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="190"/>
        <source>Folders</source>
        <translation>Kansiot</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="214"/>
        <source>Content</source>
        <translation>Sisältö</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="220"/>
        <source>File contains:</source>
        <translation>Tiedosto sisältää:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="240"/>
        <source>&amp;Use regular expression</source>
        <translation>&amp;Käytä säännöllistä lauseketta</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="267"/>
        <source>Properties</source>
        <translation>Ominaisuudet</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="273"/>
        <source>File Size:</source>
        <translation>Tiedostokoko:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="281"/>
        <source>Larger than:</source>
        <translation>Suurempi kuin:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="302"/>
        <location filename="../filesearch.ui" line="346"/>
        <source>Bytes</source>
        <translation>tavua</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="307"/>
        <location filename="../filesearch.ui" line="351"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="312"/>
        <location filename="../filesearch.ui" line="356"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="317"/>
        <location filename="../filesearch.ui" line="361"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="325"/>
        <source>Smaller than:</source>
        <translation>Pienempi kuin:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="51"/>
        <source>Case sensitive</source>
        <translation>Kirjainkokoerotus</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="125"/>
        <source>Search in subdirectories</source>
        <translation>Etsi alihakemistoista</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="233"/>
        <source>Case sensiti&amp;ve</source>
        <translation>K&amp;irjainkokoerotus</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="377"/>
        <source>Last Modified Time:</source>
        <translation>Viimeksi muokattu:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="385"/>
        <source>Earlier than:</source>
        <translation>Aiemmin kuin:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="402"/>
        <source>Later than:</source>
        <translation>Myöhemmin kuin:</translation>
    </message>
</context>
</TS>
